@@ -19,6 +19,7 @@
 
 import xml.dom.minidom
 import uuid
+import xml.sax.saxutils as saxutils
 
 from GTG import _
 from GTG.tools.dates import date_today, no_date, Date
@@ -97,12 +98,6 @@ class Task:
 
     def get_title(self):
         return self.title
-        
-    def get_titles(self, list):
-        list.append(self.title)
-        for task in self.get_subtasks():
-            list = task.get_titles(list)
-        return list
 
     #Return True if the title was changed.
     #False if the title was already the same.
@@ -174,10 +169,10 @@ class Task:
     def is_in_workview(self,tag=None):
         result = True
         if self.is_workable() and self.is_started()\
-                              and self.get_status() == "Active" :
+                              and self.get_status() == "Active":
             for t in self.get_tags():
                 if t.get_attribute("nonworkview") == "True" and \
-                                t != tag :
+                                t != tag:
                     result = False
         else:
             result = False
@@ -190,7 +185,7 @@ class Task:
         self.modified = string
 
     def set_due_date(self, fulldate):
-    	assert(isinstance(fulldate, Date))
+        assert(isinstance(fulldate, Date))
         self.due_date = fulldate
         self.sync()
 
@@ -202,31 +197,51 @@ class Task:
             #Here we compare with the parent's due date
             pardate = self.req.get_task(par).get_due_date()
             if pardate and zedate > pardate:
-            	zedate = pardate
+                zedate = pardate
         
         return zedate
 
     def set_start_date(self, fulldate):
-    	assert(isinstance(fulldate, Date))
+        assert(isinstance(fulldate, Date))
         self.start_date = fulldate
-        # why don't we sync here if we do in set_due_date?
+        self.sync()
 
     def get_start_date(self):
         return self.start_date
 
     def is_started(self):
         if self.start_date:
+            #Seems like pylint falsely assumes that subtraction always results
+            #in an object of the same type. The subtraction of dates 
+            #results in a datetime.timedelta object 
+            #that does have a 'days' member.
             difference = date_today() - self.start_date
-            return difference.days >= 0
+            if difference.days == 0:
+                # Don't count today's tasks started until morning
+                return datetime.now().hour > 4
+            else:
+                return difference.days > 0 #pylint: disable-msg=E1101
         else:
             return True
 
+    def set_closed_date(self, fulldate):
+        assert(isinstance(fulldate, Date))
+        self.closed_date = fulldate
+        self.sync()
+        
     def get_closed_date(self):
         return self.closed_date
 
     def get_days_left(self):
         due_date = self.get_due_date()
         return due_date.days_left()
+    
+    def get_days_late(self):
+        due_date = self.get_due_date()
+        if due_date == no_date:
+            return None
+        closed_date = self.get_closed_date()
+        return (closed_date - due_date).days
 
     def get_text(self):
         #defensive programmtion to avoid returning None
@@ -235,7 +250,7 @@ class Task:
         else:
             return ""
 
-    def get_excerpt(self, lines=0, char=0):
+    def get_excerpt(self, lines=0, char=0, strip_tags=False, strip_subtasks=True):
         """
         get_excerpt return the beginning of the content of the task.
         If "lines" is provided and different than 0, it return the number X
@@ -250,8 +265,12 @@ class Task:
         """
         #defensive programmtion to avoid returning None
         if self.content:
-            element = xml.dom.minidom.parseString(self.content)
-            txt = self.__strip_content(element)
+            txt = self.content
+            if strip_tags:
+                for tag in self.get_tags_name():
+                    txt = self._strip_tag(txt, tag)
+            element = xml.dom.minidom.parseString(txt)
+            txt = self.__strip_content(element, strip_subtasks=strip_subtasks)
             txt = txt.strip()
             #We keep the desired number of lines
             if lines > 0:
@@ -268,12 +287,16 @@ class Task:
         else:
             return ""
 
-    def __strip_content(self, element):
+    def __strip_content(self, element, strip_subtasks=False):
         txt = ""
         if element:
             for n in element.childNodes:
                 if n.nodeType == n.ELEMENT_NODE:
-                    txt += self.__strip_content(n)
+                    if strip_subtasks and n.tagName=='subtask':
+                        if txt[-2:]=='→ ':
+                            txt = txt[:-2]
+                    else:
+                        txt += self.__strip_content(n, strip_subtasks)
                 elif n.nodeType == n.TEXT_NODE:
                     txt += n.nodeValue
         return txt
@@ -317,7 +340,7 @@ class Task:
             if task.can_be_deleted:
                 task.set_start_date(self.get_start_date())
                 for t in self.get_tags():
-                    task.add_tag(t.get_name())
+                    task.tag_added(t.get_name())
 
     def remove_subtask(self, tid):
         """Removed a subtask from the task.
@@ -351,6 +374,13 @@ class Task:
         for i in self.children:
             zelist.append(self.req.get_task(i))
         return zelist
+        
+    def get_self_and_all_subtasks(self, active_only=False, tasks=[]):
+        tasks.append(self)
+        for i in self.get_subtasks():
+            if not active_only or i.status == self.STA_ACTIVE:
+                i.get_self_and_all_subtasks(active_only, tasks)
+        return tasks
 
     def get_subtask(self, tid):
         """Return the task corresponding to a given ID.
@@ -434,7 +464,7 @@ class Task:
         val = unicode(str(att_value), "UTF-8")
         self.attributes[(namespace, att_name)] = val
         self.sync()
-
+    
     def get_attribute(self, att_name, namespace=""):
         """Get the attribute C{att_name}.
 
@@ -476,9 +506,9 @@ class Task:
     def call_modified(self):
         self.req._task_modified(self.tid)
         #we also modify parents and children
-        for s in self.get_subtask_tids() :
+        for s in self.get_subtask_tids():
             self.req._task_modified(s)
-        for p in self.get_parents() :
+        for p in self.get_parents():
             self.req._task_modified(p)
 
     def _modified_update(self):
@@ -499,9 +529,16 @@ class Task:
     #return a copy of the list of tag objects
     def get_tags(self):
         return list(self.tags)
+        
+    def rename_tag(self, old, new):
+        eold = saxutils.escape(saxutils.unescape(old))
+        enew = saxutils.escape(saxutils.unescape(new))
+        self.content = self.content.replace(eold, enew)
+        self.remove_tag(old)
+        self.tag_added(new)
 
-    #This function add tag by name
-    def add_tag(self, tagname):
+    def tag_added(self, tagname):
+        "Add a tag. Does not add '@tag' to the contents. See insert_tag"
         t = self.req.new_tag(tagname.encode("UTF-8"))
         t.add_task(self.get_id())
         #Do not add the same tag twice
@@ -510,6 +547,31 @@ class Task:
             for child in self.get_subtasks():
                 if child.can_be_deleted:
                     child.add_tag(tagname)
+            return True
+    
+    def add_tag(self, tagname):
+        "Add a tag to the task and insert '@tag' into the task's content"
+        if self.tag_added(tagname):
+            c = self.content
+            
+            #strip <content>...</content> tags
+            if c.startswith('<content>'):
+                c = c[len('<content>'):]
+            if c.endswith('</content>'):
+                c = c[:-len('</content>')]
+            
+            if not c:
+                # don't need a separator if it's the only text
+                sep = ''
+            elif c.startswith('<tag>'):
+                # if content starts with a tag, make a comma-separated list
+                sep = ', '
+            else:
+                # other text at the beginning, so put the tag on its own line
+                sep = '\n\n'
+            
+            self.content = "<content><tag>%s</tag>%s%s</content>" % (
+                tagname, sep, c)
 
     #remove by tagname
     def remove_tag(self, tagname):
@@ -520,6 +582,19 @@ class Task:
             for child in self.get_subtasks():
                 if child.can_be_deleted:
                     child.remove_tag(tagname)
+        self.content = self._strip_tag(self.content, tagname)
+                       
+    def _strip_tag(self, text, tagname):
+        return (text
+                    .replace('<tag>%s</tag>\n\n'%(tagname), '') #trail \n
+                    .replace('<tag>%s</tag>, '%(tagname), '') #trail comma
+                    .replace('<tag>%s</tag>'%(tagname), '')
+                    #in case XML is missing (bug #504899)
+                    .replace('%s\n\n'%(tagname), '') 
+                    .replace('%s, '%(tagname), '') 
+                    .replace(tagname, '')
+               )
+     
 
     #tag_list is a list of tags object
     #return true if at least one of the list is in the task
