@@ -33,23 +33,39 @@ class NotificationArea:
     DEFAULT_PREFERENCES = {"start_minimized": False}
     PLUGIN_NAME = "notification_area"
     MAX_TITLE_LEN = 30
-    
+
+    class Borg:
+        """Application indicator can be instantiated only
+           once. The plugin api, when toggling the activation
+           state of a plugin, instantiates different instances
+           of the plugin class. Therefore, we need to keep
+           a reference to the indicator object. This class does that."""
+        __shared_state = {}
+        def __init__(self):
+            self.__dict__ = self.__shared_state
+            if not hasattr(self, "indicator"):
+                self.indicator = appindicator.Indicator ("gtg", \
+                                  "indicator-messages", \
+                                   appindicator.CATEGORY_APPLICATION_STATUS)
+                self.indicator.set_icon("gtg")
+
+        def get_indicator(self):
+            return self.indicator
+
+
+
     def __init__(self):
         self.minimized = False
+        if indicator_capable:
+            self.ind = self.Borg().get_indicator()
     
     def activate(self, plugin_api):
         self.plugin_api = plugin_api
-        #Create the  menu
-        self.create_static_menu()
+        #Populate and start the automatic update of the menu
+        self._initialize_automatic_menu()
         #initialize the right notification thing
         if indicator_capable:
-            #Create an indicator icon
-            if not hasattr(self, "ind"):
-                self.ind = appindicator.Indicator ("gtg", \
-                                  "indicator-messages", \
-                                   appindicator.CATEGORY_APPLICATION_STATUS)
-                self.ind.set_icon("gtg")
-                self.ind.set_menu(self.menu)
+            self.ind.set_menu(self.menu)
             self.ind.set_status(appindicator.STATUS_ACTIVE)
             self.ind.set_attention_icon("indicator-messages-new")
         else:
@@ -68,15 +84,6 @@ class NotificationArea:
         self.preference_dialog_init()
         self.preferences_load()
         self.preferences_apply(True)
-        #Connecting the signals about task changes
-        requester = self.plugin_api.get_requester()
-        requester.connect("task-added", self.on_task_added)
-        requester.connect("task-deleted", self.on_task_deleted)
-        requester.connect("task-modified", self.on_task_modified)
-        #initial menu populate, just in case the plugin is not activated at GTG
-        # startup time
-        task_list = requester.get_active_tasks_list(workable = True )
-        map(lambda t: self.add_menu_task(t), task_list)
         self.set_browser_minimize(self.browser_minimize)
 
     def deactivate(self, plugin_api):
@@ -89,6 +96,21 @@ class NotificationArea:
 
 ## Helper methods ##############################################################
 
+    def _initialize_automatic_menu(self):
+        #Create the  menu
+        self.create_static_menu()
+        #Connecting the signals about task changes
+        self.requester = self.plugin_api.get_requester()
+        self.requester.connect("task-added", self.on_task_added)
+        self.requester.connect("task-deleted", self.on_task_deleted)
+        self.requester.connect("task-modified", self.on_task_modified)
+        #initial menu populate, just in case the plugin is not activated at GTG
+        # startup time
+        task_list = self.requester.get_active_tasks_list(workable = True)
+        map(lambda tid: self.on_task_added(self.requester, tid), task_list)
+        #realizing the menu
+        self.menu.show_all()
+
     def _is_task_wanted_in_menu(self, tid):
         """Returns true if and only if the task has to be displayed
         in the notification menu - currently only if it's in the
@@ -200,8 +222,6 @@ class NotificationArea:
         menuItem = gtk.ImageMenuItem(gtk.STOCK_QUIT)
         menuItem.connect('activate', self.plugin_api.get_browser().on_close)
         self.menu.append(menuItem)
-        #realizing the menu
-        self.menu.show_all()
 
 ## Callback methods ############################################################
 
