@@ -121,7 +121,7 @@ class TaskTreeModel(gtk.GenericTreeModel):
         elif column == COL_DUE:
             return task.get_due_date().to_readable_string()
         elif column == COL_CDATE:
-            return task.get_closed_date().to_readable_string()
+            return task.get_closed_date()
         elif column == COL_CDATE_STR:
             if task.get_status() == Task.STA_DISMISSED:
                 date = "<span color='#AAAAAA'>" +\
@@ -585,6 +585,8 @@ class ClosedTaskTreeView(TaskTreeView):
         self.append_column(cdate_col)
         self.columns.insert(COL_CDATE_STR, cdate_col)
 
+        #self.get_model().set_sort_func(COL_DDATE, sort_due_date_column)
+
         # Title column
         title_col    = gtk.TreeViewColumn()
         render_text  = gtk.CellRendererText()
@@ -601,6 +603,11 @@ class ClosedTaskTreeView(TaskTreeView):
         self.set_show_expanders(False)
 
     def scroll_to_task(self, task_id):
+        def sort_due_date_column(model, iter1, iter2, data = None):
+            """should return -1 if iter1 precedes, 0 if iter1 and iter2
+               are equal, 1 otherwise  (sort order is ascending)"""
+            return 1
+        self.get_model().set_sort_func(COL_DDATE, sort_due_date_column)
         model = self.get_model()
         iter = model.get_iter_first()
         while iter:
