@@ -26,6 +26,7 @@ import sys
 import time
 
 from GTG import _
+from GTG import ngettext
 from GTG import PLUGIN_DIR
 from GTG import DATA_DIR
 from GTG.taskeditor          import GnomeConfig
@@ -55,14 +56,16 @@ class TaskEditor :
     #notes is experimental (bool)
     #taskconfig is a ConfigObj dic to save infos about tasks
     #thisisnew is True when a new task is created and opened
-    def __init__(self, requester, task, plugins,
+    def __init__(self, requester, task, plugins, taskbrowser,
                 delete_callback=None, close_callback=None,opentask_callback=None, \
                 tasktitle_callback=None, notes=False,taskconfig=None,\
-                plugin_apis=None,thisisnew=False,clipboard=None) :
+                plugin_apis=None,thisisnew=False, clipboard=None) :
         self.req = requester
         self.config = taskconfig
         self.p_apis = plugin_apis
+        self.pengine = taskbrowser.pengine
         self.time = None
+        self.taskbrowser = taskbrowser
         self.clipboard = clipboard
         self.builder = gtk.Builder() 
         self.builder.add_from_file(GnomeConfig.GLADE_FILE)
@@ -177,7 +180,6 @@ class TaskEditor :
         
         # plugins
         self.plugins = plugins
-        self.pengine = PluginEngine(PLUGIN_DIR)
         self.te_plugin_api = PluginAPI(window = self.window,
                                        config = None,
                                        data_dir = DATA_DIR,
@@ -191,10 +193,10 @@ class TaskEditor :
                                        tagpopup = None,
                                        tagview = None,
                                        task = task, 
-                                       browser = None,
+                                       browser = self.taskbrowser,
                                        texteditor = self)
         self.p_apis.append(self.te_plugin_api)
-        self.pengine.onTaskLoad(self.plugins)
+        self.pengine.onTaskLoad(self.te_plugin_api)
         
         #Putting the refresh callback at the end make the start a lot faster
         self.textview.refresh_callback(self.refresh_editor)
@@ -333,14 +335,11 @@ class TaskEditor :
                 txt = ""
             elif delay == 0:
                 txt = "Completed on time"
-            elif delay == 1:
-                txt = "Completed 1 day late"
-            elif delay > 1:
-                txt = _("Completed %s days late") %delay
-            elif delay == -1:
-                txt = "Completed 1 day early"
-            elif delay < -1:
-                txt = _("Completed %s days early") % -delay
+            elif delay >= 1:
+                txt = ngettext("Completed %(days)d day late", "Completed %(days)d days late", delay) % {'days': delay}
+            elif delay <= -1:
+                abs_delay = abs(delay)
+                txt = ngettext("Completed %(days)d day early", "Completed %(days)d days early", abs_delay) % {'days': abs_delay}
         else:
             result = self.task.get_days_left()
             if result is None:
@@ -348,13 +347,14 @@ class TaskEditor :
             elif result == 1:
                 txt = _("Due tomorrow !")
             elif result > 0:
-                txt = _("%s days left") %result
+                txt = ngettext("%(days)d day left", "%(days)d days left", result) % {'days': result}
             elif result == 0:
                 txt = _("Due today !")
             elif result == -1:
                 txt = _("Due yesterday")
             elif result < 0:
-                txt = _("Was %s days ago") % -result
+                abs_result = abs(result)
+                txt = ngettext("Was %(days)d day ago", "Was %(days)d days ago", abs_result) % {'days': abs_result}
         window_style = self.window.get_style()
         color = str(window_style.text[gtk.STATE_INSENSITIVE])
         self.dayleft_label.set_markup("<span color='"+color+"'>"+txt+"</span>")
