@@ -20,10 +20,10 @@
 from datetime import date, timedelta
 import locale
 from calendar import isleap
-from GTG import _
+from GTG import _, ngettext
 
 #setting the locale of gtg to the system locale 
-locale.setlocale(locale.LC_TIME, '')
+#locale.setlocale(locale.LC_TIME, '')
 
 class Date(object):
     def __cmp__(self, other):
@@ -46,16 +46,15 @@ class Date(object):
         if self.to_py_date() == NoDate().to_py_date():
             return None
         dleft = (self.to_py_date() - date.today()).days
-        if dleft == 1:
-            return _("Tomorrow")
-        elif dleft == 0:
+        if dleft == 0:
             return _("Today")
-        elif dleft == -1:
-            return _("Yesterday")
-        elif dleft < -1:
-            return _("%s days ago") % str(abs(dleft))
-        elif dleft > 1 and dleft <= 15:
-            return _("In %s days") % str(dleft)
+        elif dleft < 0:
+            abs_days = abs(dleft)
+            return ngettext("Yesterday", "%(days)d days ago", abs_days) % \
+                                                           {"days": abs_days}
+        elif dleft > 0 and dleft <= 15:
+            return ngettext("Tomorrow", "In %(days)d days", dleft) % \
+                                                           {"days": dleft}
         else:
             locale_format = self.__get_locale_string()
             if isleap(date.today().year):
@@ -93,9 +92,9 @@ class FuzzyDateFixed(FuzzyDate):
 	def to_py_date(self):
 		return self.offset
 
-NOW = FuzzyDate(0, 'now')
-SOON = FuzzyDate(15, 'soon')
-LATER = FuzzyDateFixed(date.max, 'later')
+NOW = FuzzyDate(0, _('now'))
+SOON = FuzzyDate(15, _('soon'))
+LATER = FuzzyDateFixed(date.max, _('later'))
 
 class RealDate(Date):
     def __init__(self, dt):
@@ -135,11 +134,11 @@ no_date = NoDate()
 #to a date
 #If the date is not correct, the function returns None
 def strtodate(stri) :
-    if stri == "now" or stri == _("now"):
+    if stri == _("now"):
         return NOW
-    elif stri == "soon" or stri == _("soon"):
+    elif stri == _("soon"):
         return SOON
-    elif stri == "later" or  stri == _("later"):
+    elif stri == _("later"):
         return LATER
         
     toreturn = None
