@@ -35,7 +35,7 @@ import time
 #our own imports
 import GTG
 from GTG import info
-from GTG import _
+from GTG import _, ngettext
 from GTG.core.task                    import Task
 from GTG.core.tagstore                import Tag
 from GTG.taskeditor.editor            import TaskEditor
@@ -759,10 +759,10 @@ class TaskBrowser:
         parenthesis = ""
         if count == 0:
             parenthesis = _("no active tasks")
-        elif count == 1:
-            parenthesis = _("1 active task")
         else:
-            parenthesis = _("%s active tasks") % count
+            parenthesis = ngettext("%(tasks)d active task", \
+                                   "%(tasks)d active tasks", \
+                                   count) % {'tasks': count}
         self.window.set_title("%s - "%parenthesis + WINDOW_TITLE)
 
     def get_canonical_date(self, arg):
@@ -776,6 +776,7 @@ class TaskBrowser:
         day_names = [_("monday"), _("tuesday"), _("wednesday"),
                      _("thursday"), _("friday"), _("saturday"),
                      _("sunday")]
+        date = no_date
         if re.match(r'\d{4}-\d{2}-\d{2}', arg):
             date = arg
         elif arg.isdigit():
@@ -786,23 +787,23 @@ class TaskBrowser:
                 date = "%i-%s-%s" % (year, arg[:2], arg[2:])
         elif arg.lower() == "today" or arg.lower() == _("today"):
             t = datetime.date.today()
-            date = "%i-%i-%i" % (t.year, t.month, t.day)
+            date = t.isoformat()
         elif arg.lower() == "tomorrow" or\
           arg.lower() == _("tomorrow"):
             t = datetime.date.today() + datetime.timedelta(days=1)
-            date = "%i-%i-%i" % (t.year, t.month, t.day)
+            date = t.isoformat()
         elif arg.lower() == "next week" or\
           arg.lower() == _("next week"):
             t = datetime.date.today() + datetime.timedelta(days=7)
-            date = "%i-%i-%i" % (t.year, t.month, t.day)
+            date = t.isoformat()
         elif arg.lower() == "next month" or\
           arg.lower() == _("next month"):
             t = datetime.date.today() + datetime.timedelta(days=30)
-            date = "%i-%i-%i" % (t.year, t.month, t.day)
+            date = t.isoformat()
         elif arg.lower() == "next year" or\
           arg.lower() == _("next year"):
             t = datetime.date.today() + datetime.timedelta(days=365)
-            date = "%i-%i-%i" % (t.year, t.month, t.day)
+            date = t.isoformat()
         elif arg.lower() in day_names_en or arg.lower() in day_names:
             today = datetime.date.today()
             today_day = today.weekday()
@@ -821,9 +822,10 @@ class TaskBrowser:
             date = "%i-%i-%i" % (year, month, day)
         elif arg in ('now', 'soon', 'later'):
             date = arg
-        else:
+        if date == str(no_date):
             return no_date
-        return strtodate(date)
+        else:
+            return strtodate(date)
 
     def open_task(self, uid,thisisnew=False):
         """Open the task identified by 'uid'.
@@ -838,7 +840,7 @@ class TaskBrowser:
             tv.present()
         elif t:
             tv = TaskEditor(
-                self.req, t, self.pengine.plugins.values(), \
+                self.req, t, self.pengine.plugins.values(), self, \
                 self.on_delete_task, self.close_task, self.open_task, \
                 self.get_tasktitle,taskconfig=self.task_config, \
                 plugin_apis=self.p_apis,thisisnew=thisisnew,\
@@ -1090,7 +1092,13 @@ class TaskBrowser:
         for tid in self.priv["collapsed_tids"]:
             if not self.req.has_task(tid):
                 self.priv["collapsed_tids"].remove(tid)
+        # plugins are deactivated
+        self.pengine.deactivate_plugins(self.p_apis)
+        #saving the various configurations
+        self.save_configuration()
 
+    def save_configuration(self):
+        """manages to save all the various GTG's configurations"""
         # Get configuration values
         tag_sidebar        = self.sidebar.get_property("visible")
         tag_sidebar_width  = self.builder.get_object("hpaned1").get_position()
@@ -1106,9 +1114,6 @@ class TaskBrowser:
         else:
             view = "default"
         
-        # plugins are deactivated
-        self.pengine.deactivate_plugins(self.p_apis)
-        
         #save opened tasks and their positions.
         open_task = []
         for otid in self.opened_task.keys():     
